#[repr(transparent)]pub struct ServoJSPrincipals(NonNull<JSPrincipals>);Expand description
An owned reference to Servo’s JSPrincipals instance.
Tuple Fields
0: NonNull<JSPrincipals>Implementations
Sourceimpl ServoJSPrincipals
impl ServoJSPrincipals
Sourcepub fn new<D: DomTypes>(origin: &MutableOrigin) -> Self
pub fn new<D: DomTypes>(origin: &MutableOrigin) -> Self
Crate a new ServoJSPrincipals with the given MutableOrigin. Note that the
resulting value will hold a shared mutable reference to origin, so any changes to
origin’s host will be reflected in the return value’s internal state.
Sourcepub unsafe fn from_raw_nonnull(raw: NonNull<JSPrincipals>) -> Self
pub unsafe fn from_raw_nonnull(raw: NonNull<JSPrincipals>) -> Self
Construct Self from a raw *mut JSPrincipals, incrementing its
reference count.
Safety
raw must point to a valid JSPrincipals value.
pub fn origin(&self) -> MutableOrigin
pub fn as_raw_nonnull(&self) -> NonNull<JSPrincipals>
pub fn as_raw(&self) -> *mut JSPrincipals